body {
  overflow: hidden;
  margin: 0;
  padding: 0;
  width: 100%;
  height: 100vh;
}

#map {
  width: 100%;
  height: calc(100vh - 304px);
}

.marker {
        display: block;
        border: none;
        border-radius: 50%;
        cursor: pointer;
        padding: 0;
}

.maplibregl-popup {
        max-width: 400px;
        font: 12px/20px 'Helvetica Neue', Arial, Helvetica, sans-serif;
        color: black;
    }