{% load i18n %}
{% load static %}

<meta charset="UTF-8">
<!--- <meta name="viewport" content="width=device-width, initial-scale=1.0"> -->
<link href="https://unpkg.com/maplibre-gl@4.7.1/dist/maplibre-gl.css" rel="stylesheet" />
<link rel="stylesheet" href="{% static 'netbox_sitemap/styles.css' %}">


<!--- start js vars -->
<input type="hidden" id="obj_id" value="{{ object_id }}">
<input type="hidden" id="map_type" value="widget">
<!--- end js vars -->

<style>
#map {
  width: 100%;
  height: calc(100% - 4px);
  margin-top: 4px;
}
</style>

<div id="map"></div>
<script type="module" src="{% static 'netbox_sitemap/app.js' %}"></script>
