# Generated by Django 5.2.7 on 2025-11-26 20:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dcim', '0215_rackreservation_status'),
        ('netbox_sitemap', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='sitemap',
            name='regions',
            field=models.ManyToManyField(blank=True, related_name='sitemaps', to='dcim.region'),
        ),
    ]